==> nextcloud-10.0.2.tar.bz2: nextcloud/apps/encryption/l10n/pl.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Brakujące hasło klucza odzyskiwania",
    "Please repeat the recovery key password" : "Proszę powtórz nowe hasło klucza odzyskiwania",
    "Repeated recovery key password does not match the provided recovery key password" : "Hasła klucza odzyskiwania nie zgadzają się",
    "Recovery key successfully enabled" : "Klucz odzyskiwania włączony",
    "Could not enable recovery key. Please check your recovery key password!" : "Nie można włączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Recovery key successfully disabled" : "Klucz odzyskiwania wyłączony",
    "Could not disable recovery key. Please check your recovery key password!" : "Nie można wyłączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Missing parameters" : "Brakujące dane",
    "Please provide the old recovery password" : "Podaj stare hasło odzyskiwania",
    "Please provide a new recovery password" : "Podaj nowe hasło odzyskiwania",
    "Please repeat the new recovery password" : "Proszę powtórz nowe hasło odzyskiwania",
    "Password successfully changed." : "Zmiana hasła udana.",
    "Could not change the password. Maybe the old password was not correct." : "Nie można zmienić hasła. Może stare hasło nie było poprawne.",
    "Recovery Key disabled" : "Klucz odzyskiwania wyłączony",
    "Recovery Key enabled" : "Klucz odzyskiwania włączony",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nie można włączyć klucza odzyskiwania. Proszę spróbować ponownie lub skontakuj sie z administratorem",
    "Could not update the private key password." : "Nie można zmienić hasła klucza prywatnego.",
    "The old password was not correct, please try again." : "Stare hasło nie było poprawne. Spróbuj jeszcze raz.",
    "The current log-in password was not correct, please try again." : "Obecne hasło logowania nie było poprawne. Spróbuj ponownie.",
    "Private key password successfully updated." : "Pomyślnie zaktualizowano hasło klucza prywatnego.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Musisz przenieść swoje klucze szyfrowania ze starego sposobu szyfrowania (Nextcloud <= 8,0) na nowy. Proszę uruchomić 'occ encryption:migrate' lub skontaktować się z administratorem",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Nieprawidłowy klucz prywatny do szyfrowania aplikacji. Należy zaktualizować hasło klucza prywatnego w ustawieniach osobistych, aby odzyskać dostęp do zaszyfrowanych plików.",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Szyfrowanie w aplikacji jest włączone, ale klucze nie są zainicjowane. Prosimy wylogować się i ponownie zalogować się.",
    "Encryption app is enabled and ready" : "Szyfrowanie aplikacja jest włączone i gotowe",
    "Bad Signature" : "Zła sygnatura",
    "Missing Signature" : "Brakująca sygnatura",
    "one-time password for server-side-encryption" : "jednorazowe hasło do serwera szyfrowania strony",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nie można odszyfrować tego pliku, prawdopodobnie jest to plik udostępniony. Poproś właściciela pliku o ponowne udostępnianie pliku Tobie.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nie można odczytać tego pliku, prawdopodobnie plik nie jest współdzielony. Proszę zwrócić się do właściciela pliku, aby udostępnił go dla Ciebie.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hej tam,\n\nadmin włączył szyfrowanie po stronie serwera. Twoje pliki zostały zaszyfrowane przy użyciu hasła '%s'.\n\nProszę zalogować się do interfejsu internetowego, przejdź do sekcji Nextcloud podstawowy moduł szyfrowania, następnie osobiste ustawienia i zaktualizuj hasło szyfrowania wpisując aktualny login, w polu stare hasło logowania wpisz stare hasło, a następnie aktualne hasło.\n\n",
    "The share will expire on %s." : "Ten zasób wygaśnie %s",
    "Cheers!" : "Dzięki!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hej tam,<br><br>admin włączył szyfrowanie po stronie serwera. Twoje pliki zostały zaszyfrowane przy użyciu hasła <strong>%s</strong>.<br><br>Proszę zalogować się do interfejsu internetowego, przejdź do sekcji Nextcloud podstawowy moduł szyfrowania, następnie osobiste ustawienia i zaktualizuj hasło szyfrowania wpisując aktualny login, w polu stare hasło logowania wpisz stare hasło, a następnie aktualne hasło.<br><br>",
    "Default encryption module" : "Domyślny moduł szyfrujący",
    "Encrypt the home storage" : "Szyfrowanie przechowywanie w domu",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Włączenie tej opcji spowoduje szyfrowanie wszystkich plików zapisanych na pamięci wewnętrznej. W innym wypadku szyfrowane będą tylko pliki na pamięci zewnętrznej.",
    "Enable recovery key" : "Włącz klucz odzyskiwania",
    "Disable recovery key" : "Wyłącz klucz odzyskiwania",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Kluczem do odzyskiwania jest dodatkowy klucz szyfrujący, który służy do szyfrowania plików. Umożliwia on odzyskanie plików użytkownika, jeśli użytkownik zapomni swoje hasło.",
    "Recovery key password" : "Hasło klucza odzyskiwania",
    "Repeat recovery key password" : "Powtórz hasło klucza odzyskiwania",
    "Change recovery key password:" : "Zmień hasło klucza odzyskiwania",
    "Old recovery key password" : "Stare hasło klucza odzyskiwania",
    "New recovery key password" : "Nowe hasło klucza odzyskiwania",
    "Repeat new recovery key password" : "Powtórz nowe hasło klucza odzyskiwania",
    "Change Password" : "Zmień hasło",
    "Basic encryption module" : "Podstawowy moduł szyfrujący",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacja szyfrująca jest aktywna, ale twoje klucze nie zostały zainicjowane, prosze wyloguj się i zaloguj ponownie.",
    "Your private key password no longer matches your log-in password." : "Hasło Twojego klucza prywatnego nie pasuje już do Twojego hasła logowania.",
    "Set your old private key password to your current log-in password:" : "Ustaw stare hasło klucza prywatnego na aktualne hasło logowania:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Jeśli nie pamiętasz swojego starego hasła, poproś swojego administratora, aby odzyskać pliki.",
    "Old log-in password" : "Stare hasło logowania",
    "Current log-in password" : "Bieżące hasło logowania",
    "Update Private Key Password" : "Aktualizacja hasła klucza prywatnego",
    "Enable password recovery:" : "Włącz hasło odzyskiwania:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Włączenie tej opcji umożliwia otrzymać dostęp do zaszyfrowanych plików w przypadku utraty hasła",
    "Enabled" : "Włączone",
    "Disabled" : "Wyłączone",
    "You need to migrate your encryption keys from the old encryption (Nextcloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Musisz przenieść swoje klucze szyfrowania ze starego sposobu szyfrowania (Nextcloud <= 8,0) na nowy. Proszę uruchomić 'occ encryption:migrate' lub skontaktować się z administratorem",
    "Invalid private key for Encryption App. Please update your private key password in your personal settings to recover access to your encrypted files." : "Nieprawidłowy klucz prywatny do szyfrowania aplikacji. Należy zaktualizować hasło klucza prywatnego w ustawieniach osobistych, aby odzyskać dostęp do zaszyfrowanych plików.",
    "Encryption App is enabled and ready" : "Szyfrowanie aplikacji jest włączone i gotowe",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'Nextcloud basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hej tam, \n\nadmin włączył szyfrowanie po stronie serwera. Twoje pliki zostały zaszyfrowane przy użyciu hasła '%s'.\n\nProszę zalogować się do interfejsu internetowego, przejdź do sekcji Nextcloud podstawowy moduł szyfrowania, następnie osobiste ustawienia i zaktualizuj hasło szyfrowania wpisując aktualny login, w polu stare hasło logowania wpisz stare hasło, a następnie aktualne hasło.\n\n",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"Nextcloud basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hej tam,<br><br>admin włączył szyfrowanie po stronie serwera. Twoje pliki zostały zaszyfrowane przy użyciu hasła <strong>%s</strong>.<br><br>Proszę zalogować się do interfejsu internetowego, przejdź do sekcji Nextcloud podstawowy moduł szyfrowania, następnie osobiste ustawienia i zaktualizuj hasło szyfrowania wpisując aktualny login, w polu stare hasło logowania wpisz stare hasło, a następnie aktualne hasło.<br><br>",
    "Nextcloud basic encryption module" : "Podstawowy moduł szyfrujący Nextcloud"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/encryption/l10n/pl.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Brakujące hasło klucza odzyskiwania",
    "Please repeat the recovery key password" : "Proszę powtórz nowe hasło klucza odzyskiwania",
    "Repeated recovery key password does not match the provided recovery key password" : "Hasła klucza odzyskiwania nie zgadzają się",
    "Recovery key successfully enabled" : "Klucz odzyskiwania włączony",
    "Could not enable recovery key. Please check your recovery key password!" : "Nie można włączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Recovery key successfully disabled" : "Klucz odzyskiwania wyłączony",
    "Could not disable recovery key. Please check your recovery key password!" : "Nie można wyłączyć klucza odzyskiwania. Proszę sprawdzić swoje hasło odzyskiwania!",
    "Missing parameters" : "Brakujące dane",
    "Please provide the old recovery password" : "Podaj stare hasło odzyskiwania",
    "Please provide a new recovery password" : "Podaj nowe hasło odzyskiwania",
    "Please repeat the new recovery password" : "Proszę powtórz nowe hasło odzyskiwania",
    "Password successfully changed." : "Zmiana hasła udana.",
    "Could not change the password. Maybe the old password was not correct." : "Nie można zmienić hasła. Może stare hasło nie było poprawne.",
    "Recovery Key disabled" : "Klucz odzyskiwania wyłączony",
    "Recovery Key enabled" : "Klucz odzyskiwania włączony",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nie można włączyć klucza odzyskiwania. Proszę spróbować ponownie lub skontakuj sie z administratorem",
    "Could not update the private key password." : "Nie można zmienić hasła klucza prywatnego.",
    "The old password was not correct, please try again." : "Stare hasło nie było poprawne. Spróbuj jeszcze raz.",
    "The current log-in password was not correct, please try again." : "Obecne hasło logowania nie było poprawne. Spróbuj ponownie.",
    "Private key password successfully updated." : "Pomyślnie zaktualizowano hasło klucza prywatnego.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please run 'occ encryption:migrate' or contact your administrator" : "Musisz przenieść swoje klucze szyfrowania ze starego sposobu szyfrowania (Nextcloud <= 8,0) na nowy. Proszę uruchomić 'occ encryption:migrate' lub skontaktować się z administratorem",
    "Invalid private key for encryption app. Please update your private key password in your personal settings to recover access to your encrypted files." : "Nieprawidłowy klucz prywatny do szyfrowania aplikacji. Należy zaktualizować hasło klucza prywatnego w ustawieniach osobistych, aby odzyskać dostęp do zaszyfrowanych plików.",
    "Encryption App is enabled, but your keys are not initialized. Please log-out and log-in again." : "Aplikacja szyfrująca jest włączona, ale Twoje klucze nie są zainicjowane. Proszę się wylogować i zalogować ponownie.",
    "Please enable server side encryption in the admin settings in order to use the encryption module." : "Aby móc korzystać z modułu szyfrowania trzeba włączyć w panelu administratora szyfrowanie po stronie serwera. ",
    "Encryption app is enabled and ready" : "Szyfrowanie aplikacja jest włączone i gotowe",
    "Bad Signature" : "Zła sygnatura",
    "Missing Signature" : "Brakująca sygnatura",
    "one-time password for server-side-encryption" : "jednorazowe hasło do serwera szyfrowania strony",
    "Can not decrypt this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nie można odszyfrować tego pliku, prawdopodobnie jest to plik udostępniony. Poproś właściciela pliku o ponowne udostępnianie pliku Tobie.",
    "Can not read this file, probably this is a shared file. Please ask the file owner to reshare the file with you." : "Nie można odczytać tego pliku, prawdopodobnie plik nie jest współdzielony. Proszę zwrócić się do właściciela pliku, aby udostępnił go dla Ciebie.",
    "Hey there,\n\nthe admin enabled server-side-encryption. Your files were encrypted using the password '%s'.\n\nPlease login to the web interface, go to the section 'basic encryption module' of your personal settings and update your encryption password by entering this password into the 'old log-in password' field and your current login-password.\n\n" : "Hej tam,\n\nadmin włączył szyfrowanie po stronie serwera. Twoje pliki zostały zaszyfrowane przy użyciu hasła '%s'.\n\nProszę zalogować się do interfejsu internetowego, przejdź do sekcji Nextcloud podstawowy moduł szyfrowania, następnie osobiste ustawienia i zaktualizuj hasło szyfrowania wpisując aktualny login, w polu stare hasło logowania wpisz stare hasło, a następnie aktualne hasło.\n\n",
    "The share will expire on %s." : "Ten zasób wygaśnie %s",
    "Cheers!" : "Dzięki!",
    "Hey there,<br><br>the admin enabled server-side-encryption. Your files were encrypted using the password <strong>%s</strong>.<br><br>Please login to the web interface, go to the section \"basic encryption module\" of your personal settings and update your encryption password by entering this password into the \"old log-in password\" field and your current login-password.<br><br>" : "Hej tam,<br><br>admin włączył szyfrowanie po stronie serwera. Twoje pliki zostały zaszyfrowane przy użyciu hasła <strong>%s</strong>.<br><br>Proszę zalogować się do interfejsu internetowego, przejdź do sekcji Nextcloud podstawowy moduł szyfrowania, następnie osobiste ustawienia i zaktualizuj hasło szyfrowania wpisując aktualny login, w polu stare hasło logowania wpisz stare hasło, a następnie aktualne hasło.<br><br>",
    "Default encryption module" : "Domyślny moduł szyfrujący",
    "Encryption app is enabled but your keys are not initialized, please log-out and log-in again" : "Szyfrowanie w aplikacji jest włączone, ale klucze nie są zainicjowane. Prosimy wylogować się i ponownie zalogować się.",
    "Encrypt the home storage" : "Szyfrowanie przechowywanie w domu",
    "Enabling this option encrypts all files stored on the main storage, otherwise only files on external storage will be encrypted" : "Włączenie tej opcji spowoduje szyfrowanie wszystkich plików zapisanych na pamięci wewnętrznej. W innym wypadku szyfrowane będą tylko pliki na pamięci zewnętrznej.",
    "Enable recovery key" : "Włącz klucz odzyskiwania",
    "Disable recovery key" : "Wyłącz klucz odzyskiwania",
    "The recovery key is an extra encryption key that is used to encrypt files. It allows recovery of a user's files if the user forgets his or her password." : "Kluczem do odzyskiwania jest dodatkowy klucz szyfrujący, który służy do szyfrowania plików. Umożliwia on odzyskanie plików użytkownika, jeśli użytkownik zapomni swoje hasło.",
    "Recovery key password" : "Hasło klucza odzyskiwania",
    "Repeat recovery key password" : "Powtórz hasło klucza odzyskiwania",
    "Change recovery key password:" : "Zmień hasło klucza odzyskiwania",
    "Old recovery key password" : "Stare hasło klucza odzyskiwania",
    "New recovery key password" : "Nowe hasło klucza odzyskiwania",
    "Repeat new recovery key password" : "Powtórz nowe hasło klucza odzyskiwania",
    "Change Password" : "Zmień hasło",
    "Basic encryption module" : "Podstawowy moduł szyfrujący",
    "Your private key password no longer matches your log-in password." : "Hasło Twojego klucza prywatnego nie pasuje już do Twojego hasła logowania.",
    "Set your old private key password to your current log-in password:" : "Ustaw stare hasło klucza prywatnego na aktualne hasło logowania:",
    " If you don't remember your old password you can ask your administrator to recover your files." : "Jeśli nie pamiętasz swojego starego hasła, poproś swojego administratora, aby odzyskać pliki.",
    "Old log-in password" : "Stare hasło logowania",
    "Current log-in password" : "Bieżące hasło logowania",
    "Update Private Key Password" : "Aktualizacja hasła klucza prywatnego",
    "Enable password recovery:" : "Włącz hasło odzyskiwania:",
    "Enabling this option will allow you to reobtain access to your encrypted files in case of password loss" : "Włączenie tej opcji umożliwia otrzymać dostęp do zaszyfrowanych plików w przypadku utraty hasła",
    "Enabled" : "Włączone",
    "Disabled" : "Wyłączone",
    "Encryption App is enabled but your keys are not initialized, please log-out and log-in again" : "Aplikacja szyfrująca jest aktywna, ale Twoje klucze nie zostały zainicjowane, proszę wyloguj się i zaloguj ponownie."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
